[Pkg-owncloud-commits] [owncloud] 52/90: Increase initial user count to 50

David Prévot taffit at moszumanska.debian.org
Fri Feb 6 21:10:51 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository owncloud.

commit 616fd4b54aa8c7fed6f2d8a385bcf50867645b29
Author: Morris Jobke <hey at morrisjobke.de>
Date:   Fri Jan 16 18:04:29 2015 +0100

    Increase initial user count to 50
    
    * fix initial user count if you have a big screen (or a portrait screen)
---
 settings/js/users/users.js | 6 +++---
 settings/users.php         | 4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/settings/users.php b/settings/users.php
index 94dda43..b6654e3 100644
--- a/settings/users.php
+++ b/settings/users.php
@@ -32,7 +32,7 @@ $recoveryAdminEnabled = OC_App::isEnabled('files_encryption') &&
 					    OC_Appconfig::getValue( 'files_encryption', 'recoveryAdminEnabled' );
 
 if($isAdmin) {
-	$accessibleUsers = OC_User::getDisplayNames('', 30);
+	$accessibleUsers = OC_User::getDisplayNames('', 50);
 	$subadmins = OC_SubAdmin::getAllSubAdmins();
 }else{
 	/* Retrieve group IDs from $groups array, so we can pass that information into OC_Group::displayNamesInGroups() */
@@ -42,7 +42,7 @@ if($isAdmin) {
 			$gids[] = $group['id'];
 		}
 	}
-	$accessibleUsers = OC_Group::displayNamesInGroups($gids, '', 30);
+	$accessibleUsers = OC_Group::displayNamesInGroups($gids, '', 50);
 	$subadmins = false;
 }
 

diff --git a/settings/js/users/users.js b/settings/js/users/users.js
index 63bba72..db76ed0 100644
--- a/settings/js/users/users.js
+++ b/settings/js/users/users.js
@@ -12,7 +12,7 @@ var filter;
 
 var UserList = {
 	availableGroups: [],
-	offset: 30, //The first 30 users are there. No prob, if less in total.
+	offset: 50, //The first 30 users are there. No prob, if less in total.
 				//hardcoded in settings/users.php
 
 	usersToLoad: 10, //So many users will be loaded when user scrolls down
@@ -215,11 +215,11 @@ var UserList = {
 		}
 	},
 	checkUsersToLoad: function() {
 		//30 shall be loaded initially, from then on always 10 upon scrolling
 		if(UserList.isEmpty === false) {
 			UserList.usersToLoad = 10;
 		} else {
-			UserList.usersToLoad = 30;
+			UserList.usersToLoad = 50;
 		}
 	},
 	empty: function() {
@@ -215,11 +215,11 @@ var UserList = {
 	},
 	checkUsersToLoad: function() {
-		//30 shall be loaded initially, from then on always 10 upon scrolling
+		//50 shall be loaded initially, from then on always 10 upon scrolling
 		if(UserList.isEmpty === false) {
 			UserList.usersToLoad = 10;
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud.git



More information about the Pkg-owncloud-commits mailing list